@@ -1,3 +1,8 @@
+if (jQuery != undefined) {
+    var django = {
+        'jQuery':jQuery,
+    }
+}
 (function($) {
     
     window.geopositionMapInit = function() {
@@ -102,4 +107,4 @@
         $script.attr('src', 'http://maps.google.com/maps/api/js?sensor=false&callback=geopositionMapInit');
         $script.appendTo('body');
     });
-})(django.jQuery);
\ No newline at end of file
+})(django.jQuery);
